@@ -20,8 +20,8 @@ import pyzo
 from pyzo.core.icons import IconArtist
 from pyzo.core import commandline
 from pyzo.core.statusbar import StatusBar
-from pyzo.util import qt
-from pyzo.util.qt import QtCore, QtGui, QtWidgets
+from pyzo import qt
+from pyzo.qt import QtCore, QtGui, QtWidgets
 from pyzo.core.splash import SplashWidget
 from pyzo.util import paths
 from pyzo.util import zon as ssdf  # zon is ssdf-light
@@ -71,8 +71,8 @@ class MainWindow(QtWidgets.QMainWindow):
         # Init dockwidget settings
         self.setTabPosition(QtCore.Qt.AllDockWidgetAreas, QtWidgets.QTabWidget.South)
         self.setDockOptions(
-            QtWidgets.QMainWindow.AllowNestedDocks
-            | QtWidgets.QMainWindow.AllowTabbedDocks
+            QtWidgets.QMainWindow.AllowTabbedDocks
+            | QtWidgets.QMainWindow.AllowNestedDocks
             # |  QtWidgets.QMainWindow.AnimatedDocks
         )
 
@@ -88,7 +88,7 @@ class MainWindow(QtWidgets.QMainWindow):
 
         # Hold the splash screen if needed
         while time.time() < splash_timeout:
-            QtWidgets.qApp.flush()
+            QtWidgets.qApp.sendPostedEvents()
             QtWidgets.qApp.processEvents()
             time.sleep(0.05)
 
@@ -137,12 +137,11 @@ class MainWindow(QtWidgets.QMainWindow):
         self._ispainted = False
         self.update()
         while not self._ispainted:
-            QtWidgets.qApp.flush()
+            QtWidgets.qApp.sendPostedEvents()
             QtWidgets.qApp.processEvents()
             time.sleep(0.01)
 
     def _populate(self):
-
         # Delayed imports
         from pyzo.core.editorTabs import EditorTabs
         from pyzo.core.shellStack import ShellStackWidget
@@ -341,7 +340,7 @@ class MainWindow(QtWidgets.QMainWindow):
         """Override close event handler."""
 
         # Are we restaring?
-        restarting = time.time() - self._closeflag < 1.0
+        restarting = time.time() - self._closeflag < 1.0  # noqa: F841
 
         # Save settings
         pyzo.saveConfig()
@@ -393,12 +392,6 @@ class MainWindow(QtWidgets.QMainWindow):
         # Proceed as normal
         QtWidgets.QMainWindow.closeEvent(self, event)
 
-        # Harder exit to prevent segfault. Not really a solution,
-        # but it does the job until Pyside gets fixed.
-        if sys.version_info >= (3, 3, 0) and not restarting:
-            if hasattr(os, "_exit"):
-                os._exit(0)
-
     def restart(self):
         """Restart Pyzo."""
 
@@ -428,7 +421,6 @@ class MainWindow(QtWidgets.QMainWindow):
             os.execv(sys.executable, args)
 
     def createPopupMenu(self):
-
         # Init menu
         menu = QtWidgets.QMenu()
 
@@ -524,7 +516,7 @@ def loadFonts():
     fontDir = os.path.join(pyzo.pyzoDir, "resources", "fonts")
 
     # Get database object
-    db = QtGui.QFontDatabase()
+    db = QtGui.QFontDatabase  # static class
 
     # Set default font
     pyzo.codeeditor.Manager.setDefaultFontFamily("DejaVu Sans Mono")
