@@ -131,7 +131,6 @@ class PyzoInterpreter:
     # - support for magic commands
 
     def __init__(self, locals, filename="<console>"):
-
         # Init variables for locals and globals (globals only for debugging)
         self.locals = locals
         self.globals = None
@@ -611,7 +610,6 @@ class PyzoInterpreter:
     def process_commands(self):
         """Do one iteration of processing commands (the REPL)."""
         try:
-
             self._process_commands()
 
         except SystemExit:
@@ -629,7 +627,6 @@ class PyzoInterpreter:
             self.guiApp.quit()  # Is sys.exit() by default
 
     def _process_commands(self):
-
         # Run startup code/script inside the loop (only the first time)
         # so that keyboard interrupt will work
         if self._codeToRunOnStartup:
@@ -878,6 +875,10 @@ class PyzoInterpreter:
             if self._ipython:
                 self._ipython.execution_count += 1
 
+        # Bring fname to the canonical form so that pdb recognizes the breakpoints,
+        # otherwise filename r"C:\..." would be different from canonical form r"c:\..."
+        fname = self.debugger.canonic(fname)
+
         # Put the line number in the filename (if necessary)
         # Note that we could store the line offset in the _codeCollection,
         # but then we cannot retrieve it for syntax errors.
