@@ -29,8 +29,7 @@ iconprovider = QtWidgets.QFileIconProvider()
 
 
 def addIconOverlays(icon, *overlays, offset=(8, 0), overlay_offset=(0, 0)):
-    """ Create an overlay for an icon.
-    """
+    """Create an overlay for an icon."""
     # Create painter and pixmap
     pm0 = QtGui.QPixmap(16 + offset[0], 16)  # icon.pixmap(16+offset[0],16+offset[1])
     pm0.fill(QtGui.QColor(0, 0, 0, 0))
@@ -49,7 +48,6 @@ def addIconOverlays(icon, *overlays, offset=(8, 0), overlay_offset=(0, 0)):
 
 
 def _filterFileByName(basename, filters):
-
     # Init default; return True if there are no filters
     default = True
 
@@ -70,8 +68,7 @@ def _filterFileByName(basename, filters):
 
 
 def createMounts(browser, tree):
-    """ Create items for all known mount points (i.e. drives on Windows).
-    """
+    """Create items for all known mount points (i.e. drives on Windows)."""
     fsProxy = browser._fsProxy
 
     mountPoints = getMounts()
@@ -82,8 +79,7 @@ def createMounts(browser, tree):
 
 
 def createItemsFun(browser, parent):
-    """ Create the tree widget items for a Tree or DirItem.
-    """
+    """Create the tree widget items for a Tree or DirItem."""
 
     # Get file system proxy and dir proxy for which we shall create items
     fsProxy = browser._fsProxy
@@ -105,10 +101,13 @@ def createItemsFun(browser, parent):
         dirs = []
         for entry in dirProxy.dirs():
             entry = cleanpath(entry)
-            if hideHidden and op.basename(entry).startswith("."):
-                continue  # Skip hidden files
-            if hideHidden and hasHiddenAttribute(entry):
-                continue  # Skip hidden files on Windows
+            if hideHidden:
+                if op.basename(entry).startswith("."):
+                    continue  # Skip hidden files
+                if hasHiddenAttribute(entry):
+                    continue  # Skip hidden files on Windows
+                if op.basename(entry) == "node_modules":
+                    continue
             if op.basename(entry) == "__pycache__":
                 continue
             dirs.append(entry)
@@ -135,7 +134,6 @@ def createItemsFun(browser, parent):
     files.sort(key=filename2sortkey)
 
     if not searchFilter:
-
         # Create dirs
         for path in dirs:
             starred = op.normcase(path) in starredDirs
@@ -152,7 +150,6 @@ def createItemsFun(browser, parent):
             item = FileItem(parent, fsProxy.file(path))
 
     else:
-
         # If searching, inject everything in the tree
         # And every item is hidden at first
         parent = browser._tree
@@ -180,7 +177,7 @@ def createItemsFun(browser, parent):
 
 
 def filename2sortkey(name):
-    """ Convert a file or dir name to a tuple that can be used to
+    """Convert a file or dir name to a tuple that can be used to
     logically sort them. Sorting first by extension.
     """
     # Normalize name
@@ -206,8 +203,7 @@ def filename2sortkey(name):
 
 
 class BrowserItem(QtWidgets.QTreeWidgetItem):
-    """ Abstract item in the tree widget.
-    """
+    """Abstract item in the tree widget."""
 
     def __init__(self, parent, pathProxy, *args):
         self._proxy = pathProxy
@@ -237,8 +233,7 @@ class BrowserItem(QtWidgets.QTreeWidgetItem):
         self._proxy.cancel()
 
     def clear(self):
-        """ Clear method that calls onDestroyed on its children.
-        """
+        """Clear method that calls onDestroyed on its children."""
         for i in reversed(range(self.childCount())):
             item = self.child(i)
             if hasattr(item, "onDestroyed"):
@@ -264,8 +259,7 @@ class BrowserItem(QtWidgets.QTreeWidgetItem):
 
 
 class DriveItem(BrowserItem):
-    """ Tree widget item for directories.
-    """
+    """Tree widget item for directories."""
 
     def __init__(self, parent, pathProxy):
         BrowserItem.__init__(self, parent, pathProxy)
@@ -280,8 +274,7 @@ class DriveItem(BrowserItem):
 
 
 class DirItem(BrowserItem):
-    """ Tree widget item for directories.
-    """
+    """Tree widget item for directories."""
 
     def __init__(self, parent, pathProxy, starred=False):
         self._starred = starred
@@ -327,7 +320,7 @@ class DirItem(BrowserItem):
     # No need to implement onDeleted: the parent will get a changed event.
 
     def onChanged(self):
-        """ Called when a change in the contents has occured, or when
+        """Called when a change in the contents has occured, or when
         we just activated the proxy. Update our items!
         """
         if not self.isExpanded():
@@ -337,8 +330,7 @@ class DirItem(BrowserItem):
 
 
 class FileItem(BrowserItem):
-    """ Tree widget item for files.
-    """
+    """Tree widget item for files."""
 
     def __init__(self, parent, pathProxy, mode="normal"):
         BrowserItem.__init__(self, parent, pathProxy)
@@ -407,7 +399,6 @@ class FileItem(BrowserItem):
         pass
 
     def onTaskFinished(self, task):
-
         if isinstance(task, tasks.DocstringTask):
             result = task.result()
             self.clear()  # Docstring task is done *before* peek task
@@ -435,8 +426,7 @@ class FileItem(BrowserItem):
 
 
 class SubFileItem(QtWidgets.QTreeWidgetItem):
-    """ Tree widget item for search items.
-    """
+    """Tree widget item for search items."""
 
     def __init__(self, parent, linenr, text, showlinenr=False):
         QtWidgets.QTreeWidgetItem.__init__(self, parent)
@@ -462,8 +452,7 @@ class SubFileItem(QtWidgets.QTreeWidgetItem):
 
 
 class DocstringItem(QtWidgets.QTreeWidgetItem):
-    """ Tree widget item for docstring placeholder items.
-    """
+    """Tree widget item for docstring placeholder items."""
 
     def __init__(self, parent, docstring):
         QtWidgets.QTreeWidgetItem.__init__(self, parent)
@@ -488,8 +477,7 @@ class DocstringItem(QtWidgets.QTreeWidgetItem):
 
 
 class ErrorItem(QtWidgets.QTreeWidgetItem):
-    """ Tree widget item for errors and information.
-    """
+    """Tree widget item for errors and information."""
 
     def __init__(self, parent, info):
         QtWidgets.QTreeWidgetItem.__init__(self, parent)
@@ -501,8 +489,7 @@ class ErrorItem(QtWidgets.QTreeWidgetItem):
 
 
 class SearchInfoItem(ErrorItem):
-    """ Tree widget item that displays info on the search.
-    """
+    """Tree widget item that displays info on the search."""
 
     def __init__(self, parent):
         ErrorItem.__init__(self, parent, "Searching ...")
@@ -527,7 +514,7 @@ class SearchInfoItem(ErrorItem):
 
 
 class TemporaryDirItem:
-    """ Created when searching. This object posts a requests for its contents
+    """Created when searching. This object posts a requests for its contents
     which are then processed, after which this object disbands itself.
     """
 
@@ -553,7 +540,7 @@ class TemporaryDirItem:
 
 
 class TemporaryFileItem:
-    """ Created when searching. This object posts a requests to search
+    """Created when searching. This object posts a requests to search
     its contents which are then processed, after which this object
     disbands itself, passin the proxy object to a real FileItem if the
     search had results.
@@ -589,7 +576,7 @@ class TemporaryFileItem:
 
 
 class Tree(QtWidgets.QTreeWidget):
-    """ Representation of the tree view.
+    """Representation of the tree view.
     Instances of this class are responsible for keeping the contents
     up-to-date. The Item classes above are dumb objects.
     """
@@ -628,13 +615,11 @@ class Tree(QtWidgets.QTreeWidget):
         self._proxy = None
 
     def path(self):
-        """ Get the current path shown by the treeview.
-        """
+        """Get the current path shown by the treeview."""
         return self._proxy.path()
 
     def setPath(self, path):
-        """ Set the current path shown by the treeview.
-        """
+        """Set the current path shown by the treeview."""
         # Close old proxy
         if self._proxy is not None:
             self._proxy.cancel()
@@ -663,8 +648,7 @@ class Tree(QtWidgets.QTreeWidget):
         self.dirChanged.emit(self.path())
 
     def setPathUp(self):
-        """ Go one directory up.
-        """
+        """Go one directory up."""
         newPath = op.dirname(self.path())
 
         if op.normcase(newPath) == op.normcase(self.path()):
@@ -673,7 +657,7 @@ class Tree(QtWidgets.QTreeWidget):
             self.setPath(newPath)
 
     def clear(self):
-        """ Overload the clear method to remove the items in a nice
+        """Overload the clear method to remove the items in a nice
         way, alowing the pathProxy instance to be closed correctly.
         """
         # Clear temporary (invisible) items
@@ -690,7 +674,7 @@ class Tree(QtWidgets.QTreeWidget):
         QtWidgets.QTreeWidget.clear(self)
 
     def mouseDoubleClickEvent(self, event):
-        """ Bypass expanding an item when double-cliking it.
+        """Bypass expanding an item when double-cliking it.
         Only activate the item.
         """
         item = self.itemAt(event.x(), event.y())
@@ -698,12 +682,11 @@ class Tree(QtWidgets.QTreeWidget):
             self.onItemActivated(item)
 
     def onChanged(self):
-        """ Called when our contents change or when we just changed directories.
-        """
+        """Called when our contents change or when we just changed directories."""
         self.createItems(self)
 
     def createItems(self, parent):
-        """ High level method to create the items of the tree or a DirItem.
+        """High level method to create the items of the tree or a DirItem.
         This method will handle the restoring of state etc.
         The actual filtering of entries and creation of tree widget items
         is done in the createItemsFun() function.
@@ -738,7 +721,7 @@ class Tree(QtWidgets.QTreeWidget):
             item.onClicked()
 
     def onItemActivated(self, item):
-        """ When an item is "activated", make that the new directory,
+        """When an item is "activated", make that the new directory,
         or open that file.
         """
         if hasattr(item, "onActivated"):
@@ -773,7 +756,7 @@ class Tree(QtWidgets.QTreeWidget):
         self.verticalScrollBar().setValue(self._selectedScrolling)
 
     def contextMenuTriggered(self, p):
-        """ Called when context menu is clicked """
+        """Called when context menu is clicked"""
         # Get item that was clicked on
         item = self.itemAt(p)
         if item is None:
@@ -791,7 +774,6 @@ class PopupMenu(pyzo.core.menu.Menu):
         pyzo.core.menu.Menu.__init__(self, parent, " ")
 
     def build(self):
-
         isplat = sys.platform.startswith
 
         # The star object
@@ -937,7 +919,6 @@ class PopupMenu(pyzo.core.menu.Menu):
         self._createDirOrFile(False)
 
     def _createDirOrFile(self, file=True):
-
         # Get title and label
         if file:
             title = translate("filebrowser", "Create new file")
@@ -964,7 +945,6 @@ class PopupMenu(pyzo.core.menu.Menu):
             self._item._proxy.pushTask(task)
 
     def _duplicateOrRename(self, rename):
-
         # Get dirname and filename
         dirname, filename = op.split(self._item.path())
 
